@@ -219,7 +219,7 @@ void File_Aac::program_config_element()
     BS_End(); //Byte align
     Get_B1 (comment_field_bytes,                                "comment_field_bytes");
     if (comment_field_bytes)
-        Get_Local(comment_field_bytes, comment_field_data,      "comment_field_data");
+        Get_UTF8(comment_field_bytes, comment_field_data,       "comment_field_data");
     BS_Begin(); //The stream needs continuity in the bitstream
     Element_End0();
 
@@ -231,7 +231,8 @@ void File_Aac::program_config_element()
         case  1 : Channels_Positions+=__T("Front: C"); ChannelLayout+=__T("C "); break;
         case  2 : Channels_Positions+=__T("Front: L R"); ChannelLayout+=__T("L R "); break;
         case  3 : Channels_Positions+=__T("Front: L C R"); ChannelLayout+=num_front_channel_elements==2?(front1_element_is_cpe?__T("L R C "):__T("C L R ")):__T("? ? ? "); break;
-        default : Channels_Positions+=__T("Front: "); Channels_Positions+=Ztring::ToZtring(Channels_Front); ChannelLayout+=__T("? "); //Which config?
+        case  5 : Channels_Positions+=__T("Front: L C R Lw Rw"); ChannelLayout+=num_front_channel_elements==3?(front1_element_is_cpe?__T("L R C Lw Rw "):__T("C L R Lw Rw ")):__T("? ? ? ? ? "); break;
+        default : Channels_Positions+=__T("Front:"); Channels_Positions+=Ztring::ToZtring(Channels_Side); for (size_t i=0; i<Channels_Front; i++) ChannelLayout+=__T("? "); //Which config?
     }
     switch (Channels_Side)
     {
@@ -239,21 +240,22 @@ void File_Aac::program_config_element()
         case  1 : Channels_Positions+=__T(", Side: C"); ChannelLayout+=__T("Cs "); break;
         case  2 : Channels_Positions+=__T(", Side: L R"); ChannelLayout+=__T("Ls Rs "); break;
         case  3 : Channels_Positions+=__T(", Side: L C R"); ChannelLayout+=__T("? ? ? "); break;
-        default : Channels_Positions+=__T(", Side: "); Channels_Positions+=Ztring::ToZtring(Channels_Side); ChannelLayout+=__T("? "); //Which config?
+        default : Channels_Positions+=__T(", Side: "); Channels_Positions+=Ztring::ToZtring(Channels_Side); for (size_t i=0; i< Channels_Side; i++) ChannelLayout+=__T("? "); //Which config?
     }
     switch (Channels_Back)
     {
         case  0 : break;
         case  1 : Channels_Positions+=__T(", Back: C"); ChannelLayout+=__T("Cs "); break;
-        case  2 : Channels_Positions+=__T(", Back: L R"); ChannelLayout+=__T("Rls Rrs "); break;
-        case  3 : Channels_Positions+=__T(", Back: L C R"); ChannelLayout+=__T("Rls Cs Rrs "); break;
-        default : Channels_Positions+=__T(", Back: "); Channels_Positions+=Ztring::ToZtring(Channels_Back); ChannelLayout+=__T("? "); //Which config?
+        case  2 : Channels_Positions+=__T(", Back: L R"); ChannelLayout+=__T("Lrs Rrs "); break;
+        case  3 : Channels_Positions+=__T(", Back: L C R"); ChannelLayout+=__T("Lrs Rrs Cs "); break;
+        default : Channels_Positions+=__T(", Back: "); Channels_Positions+=Ztring::ToZtring(Channels_Back); for (size_t i=0; i< Channels_Back; i++) ChannelLayout+=__T("? "); //Which config?
     }
     switch (Channels_LFE)
     {
         case  0 : break;
         case  1 : Channels_Positions+=__T(", LFE"); ChannelLayout+=__T("LFE "); break;
-        default : Channels_Positions+=__T(", LFE= "); Channels_Positions+=Ztring::ToZtring(Channels_LFE); ChannelLayout+=__T("? "); //Which config?
+        case  2 : Channels_Positions+=__T(", LFE LFE2"); ChannelLayout+=__T("LFE LFE2"); break;
+        default : Channels_Positions+=__T(", LFE: "); Channels_Positions+=Ztring::ToZtring(Channels_LFE); ChannelLayout+=__T("LFE "); for (size_t i=1; i<Channels_LFE; i++) ChannelLayout+=__T("? "); //Which config?
     }
     Channels_Positions2=Ztring::ToZtring(Channels_Front)+__T('/')
                        +Ztring::ToZtring(Channels_Side)+__T('/')
@@ -279,9 +281,9 @@ void File_Aac::program_config_element()
         Infos_General["Comment"]=comment_field_data;
 
         Infos["CodecID"].From_Number(audioObjectType);
-        Infos["Format"].From_Local("AAC");
-        Infos["Format_Profile"].From_Local(Aac_Format_Profile(audioObjectType));
-        Infos["Codec"].From_Local(Aac_audioObjectType(audioObjectType));
+        Infos["Format"].From_UTF8("AAC");
+        Infos["Format_Profile"].From_UTF8(Aac_Format_Profile(audioObjectType));
+        Infos["Codec"].From_UTF8(Aac_audioObjectType(audioObjectType));
         Infos["SamplingRate"].From_Number(Aac_sampling_frequency[sampling_frequency_index]);
         Infos["Channel(s)"].From_Number(Channels);
         Infos["ChannelPositions"]=Channels_Positions;
@@ -300,7 +302,7 @@ void File_Aac::program_config_element()
             }
             Infos["Format_Settings"]=__T("NBC"); // "Not Backward Compatible"
             Infos["Format_Settings_SBR"]=__T("Yes (NBC)"); // "Not Backward Compatible"
-            Infos["Codec"]=Ztring().From_Local(Aac_audioObjectType(audioObjectType))+__T("-SBR");
+            Infos["Codec"]=Ztring().From_UTF8(Aac_audioObjectType(audioObjectType))+__T("-SBR");
         }
 
         if (!Infos["Format_Settings_PS"].empty())
@@ -317,6 +319,13 @@ void File_Aac::raw_data_block()
 {
     raw_data_block_Pos=0;
 
+    if (audioObjectType!=2)
+    {
+        Skip_BS(Data_BS_Remain(),                               "Data");
+        Frame_Count++;
+        return; //We test only AAC LC
+    }
+
     if (sampling_frequency_index>=13)
     {
         Trusted_IsNot("(Problem)");
@@ -324,12 +333,6 @@ void File_Aac::raw_data_block()
         return;
     }
 
-    if (audioObjectType!=2)
-    {
-        Skip_BS(Data_BS_Remain(),                               "Data");
-        return; //We test only AAC LC
-    }
-
     //Parsing
     Element_Begin1("raw_data_block");
     int8u id_syn_ele=0, id_syn_ele_Previous;
@@ -367,6 +370,8 @@ void File_Aac::raw_data_block()
         Element_End0();
     }
     while(Element_IsOK() && Data_BS_Remain() && id_syn_ele!=0x07); //ID_END
+    if (Element_IsOK() && id_syn_ele!=0x07)
+        Trusted_IsNot("Not ending by END element");
     if (Element_IsOK() && Data_BS_Remain()%8)
         Skip_S1(Data_BS_Remain()%8,                             "byte_alignment");
     Element_End0();
@@ -406,7 +411,10 @@ void File_Aac::channel_pair_element()
     }
     individual_channel_stream(common_window, false);
     if (!Element_IsOK())
+    {
+        Skip_BS(Data_BS_Remain(),                               "(Problem)");
         return;
+    }
     individual_channel_stream(common_window, false);
 }
 
@@ -558,7 +566,10 @@ void File_Aac::coupling_channel_element()
     Skip_S1(2,                                                  "gain_element_scale");
     individual_channel_stream(false, false);
     if (!Element_IsOK())
+    {
+        Skip_BS(Data_BS_Remain(),                               "(Problem)");
         return;
+    }
     bool cge;
     for (size_t c=1; c<num_gain_element_lists; c++)
     {
@@ -697,18 +708,21 @@ void File_Aac::individual_channel_stream (bool common_window, bool scale_flag)
         ics_info();
     if (!Element_IsOK())
     {
+        Skip_BS(Data_BS_Remain(),                               "(Problem)");
         Element_End0();
         return;
     }
    section_data();
     if (!Element_IsOK())
     {
+        Skip_BS(Data_BS_Remain(), "?");
         Element_End0();
         return;
     }
     scale_factor_data();
     if (!Element_IsOK())
     {
+        Skip_BS(Data_BS_Remain(),                               "(Problem)");
         Element_End0();
         return;
     }
@@ -1435,7 +1449,7 @@ void File_Aac::FillInfosHEAACv2(const Ztring& Format_Settings)
         Infos["Format_Settings"].insert(0, Format_Settings);
     }
     Infos["Format_Settings_PS"] = __T("Yes (") + Format_Settings + __T(")");
-    Infos["Codec"] = Ztring().From_Local(Aac_audioObjectType(audioObjectType)) + __T("-SBR-PS");
+    Infos["Codec"] = Ztring().From_UTF8(Aac_audioObjectType(audioObjectType)) + __T("-SBR-PS");
 }
 
 //***************************************************************************
