@@ -316,21 +316,27 @@ int16u File_Aac::sbr_huff_dec(const sbr_huffman& Table, const char* Name)
 //---------------------------------------------------------------------------
 void File_Aac::sbr_extension_data(size_t End, int8u id_aac, bool crc_flag)
 {
+    if (raw_data_block_Pos>=sbrs.size())
+        sbrs.resize(raw_data_block_Pos+1);
+
     FILLING_BEGIN();
         if (Infos["Format_Settings_SBR"].empty())
         {
             Infos["Format_Profile"]=__T("HE-AAC");
             Ztring SamplingRate=Infos["SamplingRate"];
-            if (SamplingRate.empty())
+            if (SamplingRate.empty() && Frequency_b)
                 SamplingRate.From_Number(Frequency_b);
+            if (!Frequency_b && !SamplingRate.empty())
+                Frequency_b=SamplingRate.To_int64s();
             Infos["SamplingRate"].From_Number((extension_sampling_frequency_index==(int8u)-1)?(Frequency_b*2):extension_sampling_frequency, 10);
             if (MediaInfoLib::Config.LegacyStreamDisplay_Get())
             {
                 Infos["Format_Profile"]+=__T(" / LC");
                 Infos["SamplingRate"]+=__T(" / ")+SamplingRate;
             }
+            Infos["Format_Settings"]=__T("Implicit");
             Infos["Format_Settings_SBR"]=__T("Yes (Implicit)");
-            Infos["Codec"]=Ztring().From_Local(Aac_audioObjectType(audioObjectType))+__T("-SBR");
+            Infos["Codec"]=Ztring().From_UTF8(Aac_audioObjectType(audioObjectType))+__T("-SBR");
 
             if (Frame_Count_Valid<32)
                 Frame_Count_Valid=32; //We need to find the SBR header
@@ -352,16 +358,19 @@ void File_Aac::sbr_extension_data(size_t End, int8u id_aac, bool crc_flag)
                 extension_sampling_frequency_index=Aac_AudioSpecificConfig_sampling_frequency_index(extension_sampling_frequency);
             }
 
-            delete sbr;
+            delete sbrs[raw_data_block_Pos];
             sbr=new sbr_handler;
+            sbrs[raw_data_block_Pos]=sbr;
 
             sbr_header();
 
             if (!Aac_Sbr_Compute(sbr, extension_sampling_frequency_index))
             {
-                delete sbr; sbr=NULL;
+                delete sbrs[raw_data_block_Pos]; sbr=sbrs[raw_data_block_Pos]=NULL;
             }
         }
+        else
+            sbr=sbrs[raw_data_block_Pos];
     //~ }
 
     //Parsing
